/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package dk.nsp.api.configuration

import dk.nsp.api.configurationEndpoint
import dk.nsp.api.util.EpisodeOfCareHeaders
import dk.nsp.models.CheckListItem
import dk.nsp.models.DateOfBirth
import dk.nsp.models.PDFIndicator
import retrofit2.http.Body
import retrofit2.http.GET
import retrofit2.http.HeaderMap
import retrofit2.http.PUT
import retrofit2.http.Path


private const val checklistEndpoint = "$configurationEndpoint/checklist"
private const val pdfEndpoint = "$configurationEndpoint/pdf"
private const val dateOfBirthEndpoint = "$configurationEndpoint/dateOfBirth"

interface ConfigurationApi {
    @GET(checklistEndpoint)
    suspend fun getCheckedChecklistItems(@HeaderMap episodeOfCareHeader: EpisodeOfCareHeaders): List<String>

    @PUT("$checklistEndpoint/{checklistId}")
    suspend fun updateChecklistItem(
        @HeaderMap episodeOfCareHeader: EpisodeOfCareHeaders,
        @Path("checklistId") checklistId: String,
        @Body checklistItem: CheckListItem
    ): CheckListItem

    @GET(pdfEndpoint)
    suspend fun getPdfIndicator(@HeaderMap episodeOfCareHeader: EpisodeOfCareHeaders): PDFIndicator

    @PUT(pdfEndpoint)
    suspend fun updatePdfIndicator(
        @HeaderMap episodeOfCareHeader: EpisodeOfCareHeaders,
        @Body body: PDFIndicator
    ): PDFIndicator

    @GET(dateOfBirthEndpoint)
    suspend fun getDateOfBirth(@HeaderMap episodeOfCareHeader: EpisodeOfCareHeaders): DateOfBirth

    @PUT(dateOfBirthEndpoint)
    suspend fun updateDateOfBirth(
        @HeaderMap episodeOfCareHeader: EpisodeOfCareHeaders,
        @Body dateOfBirth: DateOfBirth
    ): DateOfBirth

}