/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package dk.nsp.api.notes

import dk.nsp.api.util.extensions.asyncIO
import dk.nsp.models.Note
import dk.nsp.shared.ResultWrapper
import dk.nsp.shared.Success
import kotlinx.coroutines.CoroutineScope
import kotlinx.coroutines.Deferred
import java.math.BigDecimal
import java.time.LocalDateTime

class NotesControllerMock : INotesController {
    override fun getNotes(
        scope: CoroutineScope,
        episodeOfCareIdentifier: String
    ): Deferred<ResultWrapper<List<Note>>> =
        scope.asyncIO {
            Success(
                listOf(
                    Note(
                        "Without a doubt there is something very relaxing and pleasurable about cooking and eating grilled fooThere are countless ways you can turn your grilling not only into a Without a doubt there is something very relaxing and pleasurable about cooking and eating grilled fooThere are countless ways you can turn your grilling not only into Without a doubt there is something very relaxing and pleasurable about cooking and eating grilled fooThere are countless ways you can turn your grilling not only into a Without a doubt there.",
                        "Jordemoderundersøgelse",
                        LocalDateTime.now().minusMonths(2),
                        "documentId",
                        BigDecimal(1),
                        "SorId",
                        "Claus Rasmussen"
                    ),
                    Note(
                        "Her kommer til at stå noget tekst... bla bla bla..",
                        null,
                        LocalDateTime.now().minusMonths(4),
                        "documentId",
                        BigDecimal(1),
                        "SorId",
                        "Peter Petersen"
                    )
                )
            )
        }
}