/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package dk.nsp.mingraviditet

import android.app.Application
import dagger.hilt.android.HiltAndroidApp
import io.tpa.tpalib.CrashHandling
import io.tpa.tpalib.LoggingDestination
import io.tpa.tpalib.TPA
import io.tpa.tpalib.TpaConfiguration
import io.tpa.tpalib.feedback.FeedbackInvocation
import timber.log.Timber

@HiltAndroidApp
open class App : Application() {

    override fun onCreate() {
        super.onCreate()
        setupTpa()
        setupTimber()

    }

    private fun setupTimber() {
        if (BuildConfig.DEBUG) {
            Timber.plant(Timber.DebugTree())
        }
    }

    private fun setupTpa() {
        if (!BuildConfig.DEBUG) {
            val config =
                TpaConfiguration.Builder(
                    "20338f66-19ea-4a2d-a1eb-494520fe4a40",
                    "https://insp.tpa.io/"
                )
                    .setAutomaticUpdateCheckEnabled(BuildConfig.FLAVOR != "googlePlay" && !BuildConfig.DEBUG) // This check should only run on TPA release versions
                    .setLoggingDestination(LoggingDestination.REMOTE)
                    .setCrashHandling(CrashHandling.ALWAYS_SEND)
                    .basicUpdateDialog(false)
                    .setFeedbackInvocation(FeedbackInvocation.EVENT_SHAKE)
                    .enableAnalytics(true)
                    .build()

            TPA.initialize(this, config)
        }
    }
}
