/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package dk.nsp.mingraviditet.ui.main.appointments

import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import androidx.constraintlayout.motion.widget.MotionLayout
import androidx.fragment.app.Fragment
import androidx.fragment.app.viewModels
import androidx.navigation.fragment.findNavController
import androidx.recyclerview.widget.LinearLayoutManager
import androidx.recyclerview.widget.RecyclerView
import com.commonsense.android.kotlin.views.extensions.setup
import dagger.hilt.android.AndroidEntryPoint
import dk.nsp.mingraviditet.R
import dk.nsp.mingraviditet.databinding.FragmentAppointmentsBinding
import dk.nsp.mingraviditet.ui.main.appointments.rows.AppointmentsPastHeaderRow
import dk.nsp.mingraviditet.ui.widgets.BottomInfoToggler
import dk.nsp.mingraviditet.util.android.motionlayout.MotionLayoutStateEnum
import dk.nsp.mingraviditet.util.android.recycler.DelegatingListAdapter
import dk.nsp.mingraviditet.util.extensions.*

@AndroidEntryPoint
class AppointmentsFragment : Fragment() {
    private lateinit var binding: FragmentAppointmentsBinding

    private val adapter by lazy {
        DelegatingListAdapter()
    }

    private var state: MotionLayoutStateEnum = MotionLayoutStateEnum.Start
        set(value) {
            field = value
            (binding.root as MotionLayout).handleToolbarState(value)
        }

    private val appointmentsViewModel: AppointmentsViewModel by viewModels()

    private var infoToggler: BottomInfoToggler? = null
    override fun onCreateView(
        inflater: LayoutInflater,
        container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View {
        binding = FragmentAppointmentsBinding.inflate(inflater, null, false)
        binding.toolbarTitle.setText(R.string.bottom_navigation_title_appointments)
        setupToolbarState()

        binding.recyclerview.setup(
            adapter,
            LinearLayoutManager(context, RecyclerView.VERTICAL, false)
        )

        appointmentsViewModel.rowsToShow.observe(viewLifecycleOwner) {
            adapter.submitList(it) {
                val indexOfPastHeader =
                    adapter.currentList.indexOfFirst { row -> row is AppointmentsPastHeaderRow }
                if (indexOfPastHeader != -1) {
                    binding.recyclerview.smoothSnapToPosition(indexOfPastHeader)
                }
            }
        }

        infoToggler = BottomInfoToggler(binding.bottomInfo, binding.recyclerview)

        appointmentsViewModel.navigateTo.observeIfNotHandled(viewLifecycleOwner) {
            findNavController().navigateSafe(it)
        }

        return binding.root
    }

    private fun setupToolbarState() {
        setupToolbarStateListener(binding.root) { newState ->
            state = newState
        }

        (binding.root as MotionLayout).handleToolbarState(state)
    }
}