/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2018 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package dk.nsp.mingraviditet.ui.main.appointments

import dk.nsp.mingraviditet.R
import dk.nsp.mingraviditet.util.extensions.toFullDateFormat
import dk.nsp.mingraviditet.util.extensions.toTimeFormat
import dk.nsp.models.Activity
import dk.nsp.models.ActivityPractitioner
import dk.nsp.util.TextModel
import java.util.*

fun Activity?.getDateString(): TextModel {
    if(this == null) {
        return TextModel.from(R.string.common_missing_data)
    }
    return if (plannedTime == null) {
        val gestationWeekTextModel = gestationWeek?.let { TextModel.from(it) }

        if (gestationWeekTextModel != null) {
            TextModel.from(
                R.string.appointment_details_estimated_date_value,
                gestationWeekTextModel
            )
        } else {
            TextModel.Companion.from(R.string.common_missing_data)
        }
    } else {
        TextModel.from(plannedTime!!.from.toFullDateFormat())
    }
}

fun Activity?.getTimeString(): String? {
    if(this == null) {
        return null
    }
    var time: String? = null
    if (plannedTime != null) {
        time = "Kl. ${plannedTime?.from?.toTimeFormat()} - ${plannedTime?.to?.toTimeFormat()}"
    }
    return time
}

fun Activity?.getLocationLong(): String? {
    var organizationString: String? = null

    this?.location?.let { location ->
        location.organizationName?.let { orgName ->
            organizationString = orgName
        }
        location.address?.street?.let { street ->
            organizationString += "\n"
            organizationString += street
        }
        val zip = location.address?.zip
        val city = location.address?.city
        if (zip != null && city != null) {
            organizationString += "\n$zip $city"
        }
    }

    return organizationString
}

fun Activity?.getLocationOrganizationName(): String? = this?.location?.organizationName

fun Activity?.getPractitionerInformation(): String? {
    return this?.practitioner?.getFullName()
}

fun ActivityPractitioner?.getFullName(): String {
    if(this == null) {
        return ""
    }
    return "$firstName $lastName"
}

fun Activity?.hasContactInformation(): Boolean {
    return this?.practitioner?.email != null ||  this?.practitioner?.phone != null
}

fun Activity?.hasObservationsOrNotes(): Boolean {
    return  this?.note != null ||  this?.observations?.isNotEmpty() == true
}

fun Activity?.getKindText(): String? {
    return this?.kind?.capitalize(Locale.getDefault())
}