/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package dk.nsp.mingraviditet.ui.main.appointments.details

import androidx.hilt.Assisted
import androidx.hilt.lifecycle.ViewModelInject
import androidx.lifecycle.LiveData
import androidx.lifecycle.MutableLiveData
import androidx.lifecycle.SavedStateHandle
import androidx.lifecycle.ViewModel
import dk.nsp.domain.repository.CareplanRepository
import dk.nsp.mingraviditet.util.extensions.getValue
import dk.nsp.mingraviditet.util.extensions.postSingleEvent
import dk.nsp.mingraviditet.util.livedata.SingleEvent
import dk.nsp.models.Activity

class CareplanActivityDetailsViewModel @ViewModelInject constructor(
    private val careplanRepository: CareplanRepository,
    @Assisted private val savedStateHandle: SavedStateHandle
) : ViewModel() {

    private val _careplanActivity = MutableLiveData<Activity>()
    val careplanActivity by _careplanActivity

    init {
        savedStateHandle.get<ActivityNavData>(CareplanActivityDetailsFragment.CareplanActivityDetailsDataKey)
            ?.let { navData ->
                when (navData) {
                    is ActivityNavData.WithActivity -> navData.activity
                    is ActivityNavData.WithId -> careplanRepository.getCareplanActivity(navData.activityId)
                }?.let {
                    _careplanActivity.postValue(it)
                }
            }
    }


    private val _onEmailClicked: MutableLiveData<SingleEvent<String>> = MutableLiveData()
    val onEmailClicked: LiveData<SingleEvent<String>> = _onEmailClicked
    fun onEmailClicked() {
        careplanActivity.value?.location?.email?.let {
            _onEmailClicked.postSingleEvent(it)
        }
    }

    private val _onPhoneClicked: MutableLiveData<SingleEvent<String>> = MutableLiveData()
    val onPhoneClicked: LiveData<SingleEvent<String>> = _onPhoneClicked
    fun onPhoneClicked() {
        careplanActivity.value?.location?.phone?.let {
            _onPhoneClicked.postSingleEvent(it)
        }
    }

    private val _onNavigateClicked: MutableLiveData<SingleEvent<String>> = MutableLiveData()
    val onNavigateClicked: LiveData<SingleEvent<String>> = _onNavigateClicked
    fun onNavigateClicked() {
        careplanActivity.value?.location?.address?.toString()?.let {
            _onNavigateClicked.postSingleEvent(it)
        }
    }

}