/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package dk.nsp.mingraviditet.ui.main.journal.sections.notes

import dk.nsp.mingraviditet.R
import dk.nsp.mingraviditet.databinding.JournalNoteCardRowBinding
import dk.nsp.mingraviditet.ui.adapterviews.FoldableCardData
import dk.nsp.mingraviditet.util.android.recycler.BindingViewHolder
import dk.nsp.mingraviditet.util.android.recycler.DelegationListAdapterInflater
import dk.nsp.mingraviditet.util.android.recycler.RecyclerAdapterView


// TODO: 3/11/21 This card should be able to take a Note and correct its "dot layout"
class JournalNoteCardRow(val model: FoldableCardData) :
    RecyclerAdapterView<JournalNoteCardRowBinding> {
    private var expanded = false

    override fun bindData(viewHolder: BindingViewHolder<JournalNoteCardRowBinding>) {
        with(viewHolder.binding) {
            data = model
            updateViewByState(this)

            expandCollapseButton.setOnClickListener {
                expanded = !expanded

                updateViewByState(this)
            }
        }
    }

    private fun updateViewByState(binding: JournalNoteCardRowBinding) {
        if (expanded) {
            binding.contentBody.maxLines = Int.MAX_VALUE
            binding.expandCollapseButton.setText(R.string.common_cta_collapse)
        } else {
            binding.contentBody.maxLines = 2
            binding.expandCollapseButton.setText(R.string.common_cta_expand)
        }
    }

    override val createHolderFunction: DelegationListAdapterInflater<JournalNoteCardRowBinding> =
        JournalNoteCardRowBinding::inflate
}
