/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package dk.nsp.mingraviditet.ui.main.journal.sections.sectiondetails.personaldata

import dk.nsp.mingraviditet.R
import dk.nsp.mingraviditet.util.extensions.toMediumFormat
import dk.nsp.mingraviditet.util.extensions.toTextModelOrDefault
import dk.nsp.models.Address
import dk.nsp.models.PersonName
import dk.nsp.models.PersonalDataSectionAllOfTemporaryAddress
import dk.nsp.util.TextModel

fun Address?.zipAndCityToTextModel(): TextModel {
    return TextModel.from(
        R.string.space_between_values,
        this?.zip.toTextModelOrDefault(),
        this?.city.toTextModelOrDefault()
    )
}

fun PersonalDataSectionAllOfTemporaryAddress.getFullAddressAsSingleLineTextModel(): TextModel {
    var address = ""

    this.streetAndNumber?.let { address += it }
    if (this.streetAndNumber != null && (this.zip != null || this.city != null)) {
        address += ", "
    }
    this.zip?.let { address += "$it " }
    this.city?.let { address += it }

    return if (address.isNotBlank()) {
        TextModel.from(address)
    } else {
        TextModel.from("-")
    }
}

fun PersonalDataSectionAllOfTemporaryAddress.getDurationTextModel(): TextModel {
    val from = this.validFrom?.toMediumFormat().let { it.toTextModelOrDefault() }
    val to = this.validTo?.toMediumFormat().let { it.toTextModelOrDefault() }

    return TextModel.from(R.string.dash_separated_strings, from, to)
}

val PersonName.fullName: String
    get() {
        return mutableListOf<String>().apply {
            addAll(firstNames)
            addAll(middleNames)
            add(lastName)
        }.joinToString(" ")
    }