/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package dk.nsp.domain.knowledge

import org.junit.Test


internal class ChecklistTest {

    private val nonCheckedChecklistItems = mutableListOf(
        ChecklistItem("0", "1", null, false),
        ChecklistItem("1", "2", null, false),
        ChecklistItem("2", "3", null, false),
        ChecklistItem("3", "4", null, false)
    )

    private val oneCheckedChecklistItems = mutableListOf(
        ChecklistItem("0", "1", null, true),
        ChecklistItem("1", "2", null, false),
        ChecklistItem("2", "3", null, false),
        ChecklistItem("3", "4", null, false)
    )

    private val sixChecklistItems = mutableListOf(
        ChecklistItem("0", "1", null, true),
        ChecklistItem("1", "2", null, false),
        ChecklistItem("2", "3", null, false),
        ChecklistItem("3", "4", null, false),
        ChecklistItem("4", "4", null, false),
        ChecklistItem("5", "4", null, false)
    )

    private val noCheckItemsInChecklist =
        Checklist(0, "Test Checklist", "Test description", nonCheckedChecklistItems)
    private val oneCheckedItemInChecklist =
        Checklist(1, "Checklist with one item selected", null, oneCheckedChecklistItems)
    private val sixCheckedItemsInChecklist =
        Checklist(2, "Checklist with six items", null, sixChecklistItems)

    @Test
    fun completeness() {
        assert(noCheckItemsInChecklist.completeness() == 0f)
        assert(oneCheckedItemInChecklist.completeness() == 25F)
        assert(sixCheckedItemsInChecklist.completeness() == 17F) { "Rounded to ${sixCheckedItemsInChecklist.completeness()}" }
    }


    @Test
    fun completenessAsDivision() {
        assert(noCheckItemsInChecklist.completenessAsDivision() == "0/4")
        assert(oneCheckedItemInChecklist.completenessAsDivision() == "1/4")
        assert(sixCheckedItemsInChecklist.completenessAsDivision() == "1/6")
    }

    @Test
    fun getPercentageAsString() {
        assert(noCheckItemsInChecklist.getPercentageAsString() == "0%")
        assert(oneCheckedItemInChecklist.getPercentageAsString() == "25%")
        assert(sixCheckedItemsInChecklist.getPercentageAsString() == "17%")
    }
}