/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2018 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package dk.nsp.mingraviditet.ui.main.appointments

import dk.nsp.mingraviditet.util.extensions.withTimeAtStartOfDay
import dk.nsp.models.*
import junit.framework.TestCase
import java.math.BigDecimal
import java.time.LocalDateTime

class CareplanActivitiesExtensionsKtTest : TestCase() {

    private val observations = listOf(
        Observation(
            LocalDateTime.now().minusWeeks(1),
            listOf(ObservationValues("65", "kg", "Vægt")),
            "Sygeplejerske",
            "Peter Hansen",
            true,
            "Mor",
            "actRef",
            ObservationType.Weight,
            "measurementId"
        )
    )

    private val note =
        Note(
            "Note title",
            "Content",
            LocalDateTime.now(),
            "DocumentUniqueId",
            BigDecimal.ONE,
            "AuthorSOR",
            "AutherName"
        )


    private val minimalCareplanActivity = Activity(
        Activity.Status.Expected,
        "minimalCareplanActivity",
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        null,
        LocalDateTime.now()
    )

    private val filledCareplanActivity = Activity(
        Activity.Status.Expected,
        "filledCareplanActivity",
        ActivityPractitioner("FirstName", "Test", "Testesen", "Test Org", "12345678", null, null),
        ActivityLocation(
            null,
            ActivityLocationAddress("Hedeager 5", "8200", "Aarhus N"),
            "Hospitalet",
            "12345678",
            "1@email.com",
            null
        ),
        "11+2",
        ActivityPlannedTime(
            LocalDateTime.now().withTimeAtStartOfDay().plusDays(2),
            LocalDateTime.now().withTimeAtStartOfDay().plusDays(2).plusHours(1)
        ),
        Activity.Ownership.CurrentUser,
        "Description",
        "Reference",
        Code("Code", "CodeSystem", "Display"),
        "Kind",
        "SomeId",
        note,
        observations,
        LocalDateTime.now()
    )

    fun testGetDateString() {
//        assertEquals(minimalCareplanActivity.getDateString().getString(), )
    }

    fun testGetTimeString() {
        assertEquals(null, minimalCareplanActivity.getTimeString())
//        assertEquals(filledCareplanActivity.getTimeString())
    }

    fun testGetLocation() {
        assertEquals(null, minimalCareplanActivity.getLocationLong())
        assertEquals(
            "Hospitalet\nHedeager 5\n8200 Aarhus N",
            filledCareplanActivity.getLocationLong()
        )
    }

    fun testGetPractitionerInformation() {
        assertNull(minimalCareplanActivity.getPractitionerInformation())
        assertEquals("FirstName Test", filledCareplanActivity.getPractitionerInformation())
    }

    fun testHasContactInformation() {
        assertEquals(
            "Shouldn't have any contact info",
            false,
            minimalCareplanActivity.hasContactInformation()
        )
        assertEquals(
            "Should have contact info",
            true,
            filledCareplanActivity.hasContactInformation()
        )
    }

    fun testHasObservationsOrNotes() {
        val emptyNote: Note? = null
        val emptyObservations = listOf<Observation>()

        val careplanWithEmptyObservationsAndNotes =
            minimalCareplanActivity.copy(note = emptyNote, observations = emptyObservations)

        assertEquals(false, careplanWithEmptyObservationsAndNotes.hasObservationsOrNotes())

        assertEquals(
            true,
            filledCareplanActivity.copy(observations = observations).hasObservationsOrNotes()
        )
    }
}
