#!/bin/bash
export KOTLIN_POST_PROCESS_FILE="/usr/local/bin/ktlint -F"

models_base_folder="./shared/src/main/java/dk/nsp/models"
svn_checkout_folder="./YamlWorkplace"

ktlint_location="/usr/local/bin/ktlint"

additional_properties="packageName=dk.nsp,enumPropertyNaming=PascalCase,sourceFolder=shared/src/main/java,parcelizeModels=true"
type_mappings="java.time.OffsetDateTime=java.time.LocalDateTime,java.time.LocalDate=java.time.LocalDateTime"
import_mappings="java.time.OffsetDateTime=java.time.LocalDateTime,java.time.LocalDate=java.time.LocalDateTime"
function checkout {
    svn checkout "$1" "$svn_checkout_folder"
}

function generate {
    openapi-generator generate -i "$1" -g kotlin -o "$2" --skip-validate-spec --global-property models --skip-overwrite --additional-properties=$additional_properties --type-mappings $type_mappings --import-mappings $import_mappings --enable-post-process-file
}

function preCleanup {
    rm -rf "$models_base_folder/" # remove old source files
    postCleanup # make sure all workplace-folders are clean
}

function postCleanup {
    rm -rf "$svn_checkout_folder" # clean up SVN folder
}

function checkIfToolsAreInstalled {
    local failed=false
    if ! [ -x "$(command -v openapi-generator)" ]; then
        echo '🛑  openapi-generator is not installed! ➡️ Run `brew install openapi-generator`' >&2
        failed=true
    fi

    if ! [ -x "$(command -v svn)" ]; then
        echo '🛑  svn is not installed! ➡️ Run `brew install subversion`' >&2
        failed=true
    fi

    if [ ! -f $ktlint_location ]; then
	echo '🛑  ktlint is not installed! ➡️ Run `cd /usr/local/bin && { curl -sSLO https://github.com/pinterest/ktlint/releases/download/0.40.0/ktlint ; chmod a+x ktlint ; cd -; }`' >&2
	failed=true
    fi

    if [ "$failed" = true ]; then
        exit 1
    fi
}

echo "🔧 Checking if required tools are installed on this machine ..."
checkIfToolsAreInstalled

echo "🚀 Starting generation of OpenAPI models..."
backendSvnRepo="https://svn.nspop.dk/src/libraries/gm/api/trunk/apis"
declare -a Urls=(
    "maternity-data/maternity-data-schema/src/main/resources/open-api/maternity-api.yaml"
    "maternity-feedback/maternity-feedback-schema/src/main/resources/open-api/FeedbackApi.yaml"
    "maternity-configuration/maternity-configuration-schema/src/main/resources/open-api/Configuration-api.yaml"
)

preCleanup
checkout $backendSvnRepo # SVN checks out files...
for i in "${Urls[@]}"; do
    set -- $i
    path="$1"

    echo "Starting generation of files for path: $path"
    generate "$svn_checkout_folder/$path" # Generates models in SVN location
    echo "🏁 Finished generation for path: $path"
done

postCleanup

echo "✅ All done"
