/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2020 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

package dk.nsp.domain.repository


import android.content.Context
import androidx.lifecycle.LiveData
import androidx.lifecycle.MutableLiveData
import dk.nsp.api.getBackendApiLayer
import dk.nsp.models.Note
import dk.nsp.shared.ResultWrapper
import dk.nsp.shared.Success
import dk.nsp.shared.mapSuccess
import dk.nsp.shared.util.asyncDefault
import kotlinx.coroutines.CoroutineScope
import kotlinx.coroutines.Deferred

class NotesRepository(context: Context) {
    private val notesController = context.getBackendApiLayer().notesController

    private val _notes: MutableLiveData<List<Note>> = MutableLiveData()
    val notes: LiveData<List<Note>> = _notes

    fun getNotes(
        scope: CoroutineScope,
        episodeOfCareIdentifier: String
    ): Deferred<ResultWrapper<List<Note>>> = scope.asyncDefault {
        if (_notes.value == null) {
            val notesRes = notesController.getNotes(this, episodeOfCareIdentifier).await()

            notesRes.mapSuccess {
                val notesDomain = it

                _notes.postValue(notesDomain)

                notesDomain
            }
        } else {
            // Use cache..
            Success(_notes.value!!)
        }
    }
}